API documentation
=================

.. automodule:: tsfresh
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::

    tsfresh.convenience
    tsfresh.feature_extraction
    tsfresh.feature_selection
    tsfresh.examples
    tsfresh.scripts
    tsfresh.transformers
    tsfresh.utilities


